==> cdx_toolkit-0.9.34.tar.gz: cdx_toolkit-0.9.34/tests/unit/test_capture_object.py <==
import pytest
import six

import cdx_toolkit


def test_capture_object():
    cdx_cc = cdx_toolkit.CDXFetcher(source='cc')
    cdx_ia = cdx_toolkit.CDXFetcher(source='ia')
    cdx_only = cdx_toolkit.CDXFetcher(source='https://web.archive.org/cdx/search/cdx', loglevel='DEBUG')

    url = 'example.com'
    kwargs = {'limit': 1}

    got_one = False
    for obj in cdx_only.iter(url, **kwargs):
        got_one = True
        with pytest.raises(ValueError):
            _ = obj.content
    assert got_one, 'found a capture cdx_only'

    for cdx in (cdx_cc, cdx_ia):
        got_one = False
        for obj in cdx.iter(url, **kwargs):
            got_one = True
            content = obj.content
            assert isinstance(content, six.binary_type)
            if len(content) == 0:
                # if the first capture happens to be a revisit, the content length will be zero
                pass
            else:
                assert len(content) > 100, str(obj)

            content2 = obj.content
            assert content == content2

            r = obj.fetch_warc_record()
            r2 = obj.fetch_warc_record()
            assert r == r2

            stream = obj.content_stream
            # we read the stream above, so it's at eof
            more_content = stream.read()
            assert len(more_content) == 0

            text = obj.text
            assert isinstance(text, six.string_types)
            text2 = obj.text
            assert text == text2

            # some duck-type dict texts on obj
            obj['foo'] = 'asdf'
            assert obj['foo'] == 'asdf'
            assert 'foo' in obj
            del obj['foo']

        assert got_one

==> cdx_toolkit-0.9.37.tar.gz: cdx_toolkit-0.9.37/tests/unit/test_capture_object.py <==
import pytest
import six

import cdx_toolkit


def test_capture_object():
    cdx_cc = cdx_toolkit.CDXFetcher(source='cc')
    #XXX cdx_ia = cdx_toolkit.CDXFetcher(source='ia')
    cdx_only = cdx_toolkit.CDXFetcher(source='https://web.archive.org/cdx/search/cdx', loglevel='DEBUG')

    url = 'example.com'
    kwargs = {'limit': 1}

    got_one = False
    for obj in cdx_only.iter(url, **kwargs):
        got_one = True
        with pytest.raises(ValueError):
            # we don't know how to fetch the content in this situation
            _ = obj.content
    assert got_one, 'found a capture cdx_only'

    #XXX for cdx in (cdx_cc, cdx_ia):
    for cdx in (cdx_cc,):
        got_one = False
        for obj in cdx.iter(url, **kwargs):
            got_one = True
            content = obj.content
            assert isinstance(content, six.binary_type)
            if len(content) == 0:
                # if the first capture happens to be a revisit, the content length will be zero
                pass
            else:
                assert len(content) > 100, str(obj)

            content2 = obj.content
            assert content == content2

            r = obj.fetch_warc_record()
            r2 = obj.fetch_warc_record()
            assert r == r2

            stream = obj.content_stream
            # we read the stream above, so it's at eof
            more_content = stream.read()
            assert len(more_content) == 0

            text = obj.text
            assert isinstance(text, six.string_types)
            text2 = obj.text
            assert text == text2

            # some duck-type dict texts on obj
            obj['foo'] = 'asdf'
            assert obj['foo'] == 'asdf'
            assert 'foo' in obj
            del obj['foo']

        assert got_one
